@@ -32,7 +32,7 @@ class MessageStatus(MessageStatus):
     STATUS_REDUCE_SIZE_FAILURE = 606
     STATUS_MARKET_HOURS_DENIED = 607
     STATUS_INVALID_MIN_INCREMENT = 608
-    STATUS_INVALID_SPREAD = 609
+    STATUS_POST_DENIED = 609
     STATUS_CANCEL_SUCCESS = 700
     STATUS_CANCEL_REPLACE_SUCCESS = 701
     STATUS_REDUCE_SIZE_SUCCESS = 702
